pygeodesy.hausdorff.HausdorffDegrees

Package pygeodesy :: Module hausdorff :: Class HausdorffDegrees |
[frames] | no frames]

# Class HausdorffDegrees

      object --+
               |
    named._Named --+
                   |
           Hausdorff --+
                       |
                      HausdorffDegrees

Hausdorff base class for distances from `LatLon` points in `degrees`.

Instance Methods
__init__(self, point1s, seed=None, units='', **name__kwds) New `Hausdorff...` calculator. |
directed(self, point2s, early=True) Compute only the `forward Hausdorff` distance. |
symmetric(self, point2s, early=True) Compute the combined `forward and reverse Hausdorff` distance. |
distance(self, point1, point2) Must be overloaded. |
Inherited from `Hausdorff`: `point` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Hausdorff`: `adjust`, `datum`, `kwds`, `seed`, `units`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, point1s, seed=None, units='', **name__kwds) (Constructor) |
New `Hausdorff...` calculator. Arguments: `point1s` - Initial set of points, aka the `model` or `template` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `seed` - Random sampling seed (`any`) or `None`, `0` or `False` for no random sampling. `units` - Optional, the distance units (`Unit` or `str`). `name__kwds` - Optional calculator/interpolator `name=NN` (`str`) and keyword arguments for the distance function, retrievable with property `kwds`. Raises: `HausdorffError` - Insufficient number of `point1s` or an invalid `point1`, `seed` or `units`. Overrides: object.__init__

### directed (self, point2s, early=True) |
Compute only the `forward Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Overrides: Hausdorff.directed Note: See `point2s` note at HausdorffDistanceTo.

### symmetric (self, point2s, early=True) |
Compute the combined `forward and reverse Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Overrides: Hausdorff.symmetric Note: See `point2s` note at HausdorffDistanceTo.

### distance (self, point1, point2) |
Must be overloaded. Overrides: Hausdorff.distance